References
==========

* `PRAW Source Code <https://github.com/praw-dev/praw>`_.
* `Reddit Source Code <https://github.com/reddit/reddit>`_.
  This repository has been archived and is no longer updated.
* `Reddit API Wiki Page <https://github.com/reddit/reddit/wiki/API>`_.
* `Reddit API Documentation <https://www.reddit.com/dev/api>`_.

* `Reddit Help <https://www.reddithelp.com/en>`_. Frequently asked questions
  and a knowledge base for the site.
* `Reddit Markdown Primer
  <https://www.reddit.com/wiki/markdown>`_. A guide to the Markdown formatting
  used on the site.
* `Reddit Status <https://reddit.statuspage.io/>`_.
  Indicates when Reddit is up or down.
* `r/changelog <https://www.reddit.com/r/changelog/>`_. Significant changes to
  Reddit's codebase will be announced here in non-developer speak.
* `r/redditdev <https://www.reddit.com/r/redditdev>`_. Ask questions about
  Reddit's codebase, PRAW, and other API clients here.
